From caff7965709b3c672265ca51613e1dac285c2497 Mon Sep 17 00:00:00 2001
From: Aleksander Alekseev <aleksander@timescale.com>
Date: Wed, 26 Jul 2023 16:15:38 +0300
Subject: [PATCH v2] Remove unused fields in ReorderBufferTupleBuf.

The fields node and alloc_tuple_size are no longer used. It's an
oversight in commit a4ccc1cef.

Not backpatched because of ABI compatibility.

Masahiko Sawada, reviewed by Aleksander Alekseev
Discussion: https://postgr.es/m/CAD21AoCvnuxiXXfRecp7g9+CeC35POQfhuQeJFr7_9u_Q5jc_Q@mail.gmail.com
---
 src/backend/replication/logical/reorderbuffer.c | 1 -
 src/include/replication/reorderbuffer.h         | 6 ------
 2 files changed, 7 deletions(-)

diff --git a/src/backend/replication/logical/reorderbuffer.c b/src/backend/replication/logical/reorderbuffer.c
index 26d252bd87..47913184e1 100644
--- a/src/backend/replication/logical/reorderbuffer.c
+++ b/src/backend/replication/logical/reorderbuffer.c
@@ -562,7 +562,6 @@ ReorderBufferGetTupleBuf(ReorderBuffer *rb, Size tuple_len)
 		MemoryContextAlloc(rb->tup_context,
 						   sizeof(ReorderBufferTupleBuf) +
 						   MAXIMUM_ALIGNOF + alloc_len);
-	tuple->alloc_tuple_size = alloc_len;
 	tuple->tuple.t_data = ReorderBufferTupleBufData(tuple);
 
 	return tuple;
diff --git a/src/include/replication/reorderbuffer.h b/src/include/replication/reorderbuffer.h
index 1b9db22acb..baa3442a35 100644
--- a/src/include/replication/reorderbuffer.h
+++ b/src/include/replication/reorderbuffer.h
@@ -31,15 +31,9 @@ typedef enum
 /* an individual tuple, stored in one chunk of memory */
 typedef struct ReorderBufferTupleBuf
 {
-	/* position in preallocated list */
-	slist_node	node;
-
 	/* tuple header, the interesting bit for users of logical decoding */
 	HeapTupleData tuple;
 
-	/* pre-allocated size of tuple buffer, different from tuple size */
-	Size		alloc_tuple_size;
-
 	/* actual tuple data follows */
 } ReorderBufferTupleBuf;
 
-- 
2.41.0

